<?php

if ( ! function_exists( 'micdrop_is_page_title_enabled' ) ) {
	/**
	 * Function that check is module enabled
	 */
	function micdrop_is_page_title_enabled() {
		return apply_filters( 'micdrop_filter_enable_page_title', true );
	}
}

if ( ! function_exists( 'micdrop_load_page_title' ) ) {
	/**
	 * Function which loads page template module
	 */
	function micdrop_load_page_title() {

		if ( micdrop_is_page_title_enabled() ) {
			// Include title template
			echo apply_filters( 'micdrop_filter_title_template', micdrop_get_template_part( 'title', 'templates/title' ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}

	add_action( 'micdrop_action_page_title_template', 'micdrop_load_page_title' );
}

if ( ! function_exists( 'micdrop_get_page_title_classes' ) ) {
	/**
	 * Function that return classes for page title area
	 *
	 * @return string
	 */
	function micdrop_get_page_title_classes() {
		$classes = apply_filters( 'micdrop_filter_page_title_classes', array() );

		return implode( ' ', $classes );
	}
}

if ( ! function_exists( 'micdrop_get_page_modified_title_text' ) ) {
	/**
	 * Function that return modified title
	 *
	 * @return mixed
	 */
	function micdrop_get_page_modified_title_text( $title ) {
		$line_break = micdrop_get_post_value_through_levels( 'line_break_positions' );

		if ( ! empty( $title ) && ! empty( $line_break ) ) {
			$split_title          = explode( ' ', $title );
			$line_break_positions = explode( ',', str_replace( ' ', '', $line_break ) );

			foreach ( $line_break_positions as $position ) {
				$position = intval( $position );
				if ( isset( $split_title[ $position - 1 ] ) && ! empty( $split_title[ $position - 1 ] ) ) {
					$split_title[ $position - 1 ] = $split_title[ $position - 1 ] . '<br />';
				}
			}

			$title = implode( ' ', $split_title );
		}

		return $title;
	}
}

if ( ! function_exists( 'micdrop_get_page_title_text' ) ) {
	/**
	 * Function that returns current page title text
	 */
	function micdrop_get_page_title_text() {
		$title = get_the_title( micdrop_get_page_id() );

		if ( ( is_home() && is_front_page() ) || is_singular( 'post' ) ) {
			$title = get_option( 'blogname' );
		} elseif ( is_tag() ) {
			$title = single_term_title( '', false ) . esc_html__( ' Tag', 'micdrop' );
		} elseif ( is_date() ) {
			$title = get_the_time( 'F Y' );
		} elseif ( is_author() ) {
			$title = esc_html__( 'Author: ', 'micdrop' ) . get_the_author();
		} elseif ( is_category() ) {
			$title = single_cat_title( '', false );
		} elseif ( is_archive() ) {
			$title = esc_html__( 'Archive', 'micdrop' );
		} elseif ( is_search() ) {
			$title = esc_html__( 'Search results for: ', 'micdrop' ) . get_search_query();
		} elseif ( is_404() ) {
			$title = esc_html__( '404 - Page not found', 'micdrop' );
		}

		$title = micdrop_get_page_modified_title_text( $title ); // adding line break trough options

		return apply_filters( 'micdrop_filter_page_title_text', $title );
	}
}
